@@ -1,12 +1,7 @@
 module Main (main, spec) where
 
-import Test.Hspec.Monadic
-import Test.Hspec.HUnit ()
-import Test.Hspec.QuickCheck
-import Test.HUnit
-
-shouldBe :: (Show a, Eq a) => a -> a -> Assertion
-actual `shouldBe` expected = actual @?= expected
+import Test.Hspec
+import Test.QuickCheck
 
 main :: IO ()
 main = hspec spec
@@ -18,4 +13,4 @@ spec = do
       reverse [1 :: Int, 2, 3] `shouldBe` [3, 2, 1]
 
     it "gives the original list, if applied twice" $ property $
-      \xs -> reverse (reverse xs) == (xs :: [Int])
+      \xs -> (reverse . reverse) xs == (xs :: [Int])
