@@ -5,6 +5,7 @@ module Test.Hspec.Core.Type (
 , runSpecM
 , fromSpecList
 , SpecTree (..)
+, Item (..)
 , Example (..)
 , Result (..)
 , Params (..)
@@ -34,10 +35,9 @@ import qualified Test.QuickCheck.State as QC
 import qualified Test.QuickCheck.Property as QCP
 import qualified Test.QuickCheck.IO ()
 
-import           Test.Hspec.Compat (isUserInterrupt)
+import           Test.Hspec.Core.QuickCheckUtil
 import           Control.DeepSeq (deepseq)
 
-
 type Spec = SpecM ()
 
 -- | A writer monad for `SpecTree` forests.
@@ -75,7 +75,13 @@ data Params = Params {
 -- | Internal representation of a spec.
 data SpecTree =
     SpecGroup String [SpecTree]
-  | SpecItem Bool String (Params -> IO Result)
+  | SpecItem Item
+
+data Item = Item {
+  itemIsParallelizable :: Bool
+, itemRequirement :: String
+, itemExample :: Params -> (IO () -> IO ()) -> IO Result
+}
 
 -- | The @describe@ function combines a list of specs into a larger spec.
 describe :: String -> [SpecTree] -> SpecTree
@@ -87,7 +93,7 @@ describe s = SpecGroup msg
 
 -- | Create a spec item.
 it :: Example a => String -> a -> SpecTree
-it s e = SpecItem False msg (`evaluateExample` e)
+it s e = SpecItem $ Item False msg (evaluateExample e)
   where
     msg
       | null s = "(unspecified behavior)"
@@ -95,23 +101,23 @@ it s e = SpecItem False msg (`evaluateExample` e)
 
 -- | A type class for examples.
 class Example a where
-  evaluateExample :: Params -> a -> IO Result
+  evaluateExample :: a -> Params -> (IO () -> IO ()) -> IO Result
 
 instance Example Bool where
-  evaluateExample _ b = if b then return Success else return (Fail "")
+  evaluateExample b _ _ = if b then return Success else return (Fail "")
 
 instance Example Expectation where
-  evaluateExample _ action = (action >> return Success) `E.catches` [
-      E.Handler (\(HUnitFailure err) -> (return . Fail) err)
+  evaluateExample e _ action = (action e >> return Success) `E.catches` [
+      E.Handler (\(HUnitFailure err) -> return (Fail err))
     , E.Handler (return :: Result -> IO Result)
     ]
 
 instance Example Result where
-  evaluateExample _ = return
+  evaluateExample r _ _ = return r
 
 instance Example QC.Property where
-  evaluateExample c p = do
-    r <- QC.quickCheckWithResult (paramsQuickCheckArgs c) {QC.chatty = False} (QCP.callback progressCallback p)
+  evaluateExample p c action = do
+    r <- QC.quickCheckWithResult (paramsQuickCheckArgs c) {QC.chatty = False} (QCP.callback progressCallback $ aroundProperty action p)
     when (isUserInterrupt r) $ do
       E.throwIO E.UserInterrupt
 
