@@ -1,3 +1,4 @@
+{-# LANGUAGE FlexibleInstances #-}
 -- |
 -- Stability: experimental
 --
@@ -29,6 +30,7 @@ module Test.Hspec.Formatters (
 
 , FailureRecord (..)
 , getFailMessages
+, usedSeed
 
 , getCPUTime
 , getRealTime
@@ -45,6 +47,16 @@ module Test.Hspec.Formatters (
 
 -- ** Helpers
 , formatException
+
+-- * Using custom formatters with @hspec-discover@
+-- |
+-- Anything that is an instance of `IsFormatter` can be used by
+-- @hspec-discover@ as the default formatter for a spec.  If you have a
+-- formatter @myFormatter@ in the module @Custom.Formatters@ you can use it
+-- by passing an additional argument to @hspec-discover@.
+--
+-- >{-# OPTIONS_GHC -F -pgmF hspec-discover -optF --formatter=Custom.Formatters.myFormatter #-}
+, IsFormatter (..)
 ) where
 
 import           Data.Maybe
@@ -54,6 +66,7 @@ import           Text.Printf
 import           Control.Monad (unless, forM_)
 import           Control.Applicative
 import qualified Control.Exception as E
+import           System.IO (hPutStr, hFlush)
 
 -- We use an explicit import list for "Test.Hspec.Formatters.Internal", to make
 -- sure, that we only use the public API to implement formatters.
@@ -71,6 +84,7 @@ import Test.Hspec.Formatters.Internal (
 
   , FailureRecord (..)
   , getFailMessages
+  , usedSeed
 
   , getCPUTime
   , getRealTime
@@ -84,12 +98,21 @@ import Test.Hspec.Formatters.Internal (
   , withFailColor
   )
 
+class IsFormatter a where
+  toFormatter :: a -> IO Formatter
+
+instance IsFormatter (IO Formatter) where
+  toFormatter = id
+
+instance IsFormatter Formatter where
+  toFormatter = return
 
 silent :: Formatter
 silent = Formatter {
   headerFormatter     = return ()
 , exampleGroupStarted = \_ _ _ -> return ()
 , exampleGroupDone    = return ()
+, exampleProgress     = \_ _ _ -> return ()
 , exampleSucceeded    = \_ -> return ()
 , exampleFailed       = \_ _ -> return ()
 , examplePending      = \_ _  -> return ()
@@ -115,6 +138,10 @@ specdoc = silent {
 , exampleGroupDone = do
     newParagraph
 
+, exampleProgress = \h _ p -> do
+    hPutStr h (formatProgress p)
+    hFlush h
+
 , exampleSucceeded = \(nesting, requirement) -> withSuccessColor $ do
     writeLine $ indentationFor nesting ++ "- " ++ requirement
 
@@ -130,6 +157,9 @@ specdoc = silent {
 , footerFormatter = defaultFooter
 } where
     indentationFor nesting = replicate (length nesting * 2) ' '
+    formatProgress (current, total)
+      | total == 0 = show current ++ "\r"
+      | otherwise  = show current ++ "/" ++ show total ++ "\r"
 
 
 progress :: Formatter
@@ -157,19 +187,19 @@ defaultFailedFormatter = do
   forM_ (zip [1..] failures) $ \x -> do
     formatFailure x
     writeLine ""
+  unless (null failures) $ do
+    write "Randomized with seed " >> usedSeed >>= writeLine . show
+    writeLine ""
   where
     formatFailure :: (Int, FailureRecord) -> FormatM ()
     formatFailure (n, FailureRecord path reason) = do
       write (show n ++ ") ")
+      writeLine (formatRequirement path)
       withFailColor $ do
-        write (formatRequirement path ++ " FAILED")
-        write $ case reason of
-          Right _ -> "\n"
-          Left _  -> " (uncaught exception)\n"
         unless (null err) $ do
           writeLine err
       where
-        err = either formatException id reason
+        err = either (("uncaught exception: " ++) . formatException) id reason
 
 -- | Convert an exception to a string.
 --
@@ -197,8 +227,8 @@ defaultFooter = do
         | pending /= 0 = withPendingColor
         | otherwise    = withSuccessColor
   c $ do
-    write $ quantify total   "example"
-    write (", " ++ quantify fails "failure")
+    write $ pluralize total   "example"
+    write (", " ++ pluralize fails "failure")
     unless (pending == 0) $
       write (", " ++ show pending ++ " pending")
   writeLine ""
