@@ -12,6 +12,7 @@ module Test.Hspec.Formatters.Internal (
 
 , FailureRecord (..)
 , getFailMessages
+, usedSeed
 
 , getCPUTime
 , getRealTime
@@ -26,7 +27,6 @@ module Test.Hspec.Formatters.Internal (
 
 -- * Functions for internal use
 , runFormatM
-, liftIO
 , increaseSuccessCount
 , increasePendingCount
 , increaseFailCount
@@ -41,30 +41,23 @@ import           Control.Applicative
 import           Control.Exception (SomeException, AsyncException(..), bracket_, try, throwIO)
 import           System.Console.ANSI
 import           Control.Monad.Trans.State hiding (gets, modify)
-import qualified Control.Monad.IO.Class as IOClass
+import           Control.Monad.IO.Class
 import qualified System.CPUTime as CPUTime
-import           Data.IORef
 import           Data.Time.Clock.POSIX (POSIXTime, getPOSIXTime)
 
 import           Test.Hspec.Util (Path)
+import           Test.Hspec.Compat
+import           Test.Hspec.Core.Type (Progress)
 
 -- | A lifted version of `Control.Monad.Trans.State.gets`
 gets :: (FormatterState -> a) -> FormatM a
 gets f = FormatM $ do
-  f <$> (get >>= IOClass.liftIO . readIORef)
+  f <$> (get >>= liftIO . readIORef)
 
 -- | A lifted version of `Control.Monad.Trans.State.modify`
 modify :: (FormatterState -> FormatterState) -> FormatM ()
 modify f = FormatM $ do
-  get >>= IOClass.liftIO . (`modifyIORef` f)
-
--- | A lifted version of `IOClass.liftIO`
---
--- This is meant for internal use only, and not part of the public API.  This
--- is also the reason why we do not make FormatM an instance MonadIO, so we
--- have narrow control over the visibilty of this function.
-liftIO :: IO a -> FormatM a
-liftIO action = FormatM (IOClass.liftIO action)
+  get >>= liftIO . (`modifyIORef'` f)
 
 data FormatterState = FormatterState {
   stateHandle     :: Handle
@@ -75,10 +68,15 @@ data FormatterState = FormatterState {
 , pendingCount    :: Int
 , failCount       :: Int
 , failMessages    :: [FailureRecord]
+, stateUsedSeed   :: Integer
 , cpuStartTime    :: Maybe Integer
 , startTime       :: POSIXTime
 }
 
+-- | The random seed that is used for QuickCheck.
+usedSeed :: FormatM Integer
+usedSeed = gets stateUsedSeed
+
 -- | The total number of examples encountered so far.
 totalCount :: FormatterState -> Int
 totalCount s = successCount s + pendingCount s + failCount s
@@ -86,13 +84,13 @@ totalCount s = successCount s + pendingCount s + failCount s
 -- NOTE: We use an IORef here, so that the state persists when UserInterrupt is
 -- thrown.
 newtype FormatM a = FormatM (StateT (IORef FormatterState) IO a)
-  deriving (Functor, Applicative, Monad)
+  deriving (Functor, Applicative, Monad, MonadIO)
 
-runFormatM :: Bool -> Bool -> Bool -> Handle -> FormatM a -> IO a
-runFormatM useColor produceHTML_ printCpuTime handle (FormatM action) = do
+runFormatM :: Bool -> Bool -> Bool -> Integer -> Handle -> FormatM a -> IO a
+runFormatM useColor produceHTML_ printCpuTime seed handle (FormatM action) = do
   time <- getPOSIXTime
   cpuTime <- if printCpuTime then Just <$> CPUTime.getCPUTime else pure Nothing
-  st <- newIORef (FormatterState handle useColor produceHTML_ False 0 0 0 [] cpuTime time)
+  st <- newIORef (FormatterState handle useColor produceHTML_ False 0 0 0 [] seed cpuTime time)
   evalStateT action st
 
 -- | Increase the counter for successful examples
@@ -124,7 +122,7 @@ getTotalCount :: FormatM Int
 getTotalCount = gets totalCount
 
 -- | Append to the list of accumulated failure messages.
-addFailMessage :: Path -> (Either SomeException String) -> FormatM ()
+addFailMessage :: Path -> Either SomeException String -> FormatM ()
 addFailMessage p m = modify $ \s -> s {failMessages = FailureRecord p m : failMessages s}
 
 -- | Get the list of accumulated failure messages.
@@ -147,6 +145,11 @@ data Formatter = Formatter {
 
 , exampleGroupDone    :: FormatM ()
 
+-- | used to notify the progress of the currently evaluated example
+--
+-- NOTE: This is only called when interactive/color mode.
+, exampleProgress     :: Handle -> Path -> Progress -> IO ()
+
 -- | evaluated after each successful example
 , exampleSucceeded    :: Path -> FormatM ()
 
