@@ -3,7 +3,6 @@ module Test.Hspec.Monadic {-# DEPRECATED "use \"Test.Hspec\", \"Test.Hspec.Runne
 -- * Types
   Spec
 , Example
-, Pending
 
 -- * Defining a spec
 , describe
@@ -51,4 +50,4 @@ hspecB spec = (== 0) . summaryFailures <$> hspecWith defaultConfig spec
 
 {-# DEPRECATED hHspec "use hspecWith instead" #-}         -- since 1.4.0
 hHspec :: Handle -> Spec -> IO Summary
-hHspec h = hspecWith defaultConfig {configHandle = h}
+hHspec h = hspecWith defaultConfig {configHandle = Left h}
