@@ -1,9 +1,8 @@
 module Test.Hspec.FailureReportSpec (main, spec) where
 
-import           Test.Hspec.Meta
+import           Helper
 
 import           System.IO
-import           System.IO.Silently
 import           Test.Hspec.FailureReport
 import           GHC.Paths (ghc)
 import           System.Process
@@ -16,11 +15,11 @@ spec :: Spec
 spec = do
   describe "writeFailureReport" $ do
     it "prints a warning on unexpected exceptions" $ do
-      (r, ()) <- hCapture [stderr] $ writeFailureReport (error "some error")
+      r <- hCapture_ [stderr] $ writeFailureReport (error "some error")
       r `shouldBe` "WARNING: Could not write environment variable HSPEC_FAILURES (some error)\n"
 
   -- GHCi needs to keep the environment on :reload, so that we can store
-  -- failures there.  Otherwise --re-run would not be very useful.  So we add a
+  -- failures there.  Otherwise --rerun would not be very useful.  So we add a
   -- test for that.
   describe "GHCi" $ do
     it "keeps environment variables on :reload" $ do
