@@ -1,6 +1,6 @@
 module Test.Hspec.QuickCheckSpec (main, spec) where
 
-import           Test.Hspec.Meta
+import           Helper
 
 import qualified Test.Hspec as H
 import qualified Test.Hspec.Runner as H
@@ -13,7 +13,7 @@ spec :: Spec
 spec = do
   describe "prop" $ do
     it "is a shortcut to use properties as examples" $ do
-      H.hspecWith H.defaultConfig $ do
+      silence . H.hspecResult $ do
         H.describe "read" $ do
           H.prop "is inverse to show" $ \x -> (read . show) x == (x :: Int)
       `shouldReturn` H.Summary 1 0
